def get_currency():
    currencies = [
    "INR",
    "USD",
    "EUR",
    "ACU",
    "GBP",
    "JPY",
    "AUD",
    "BGN",
    "BRL",
    "CAD",
    "CHF",
    "CNY",
    "CZK",
    "DKK",
    "HKD",
    "HRK",
    "HUF",
    "IDR",
    "ILS",
    "KRW",
    "MXN",
    "MYR",
    "NOK",
    "NZD",
    "PHP",
    "PLN",
    "RON",
    "RUB",
    "SEK",
    "SGD",
    "THB",
    "TRY",
    "ZAR",
    "TWD",
    "AED",
    "TPE"
    ]
    return currencies


def get_freight_terms():
    freight_terms = ["PREPAID", "COLLECT"]
    return freight_terms


def get_weight_uom():
    weight_uom = ["KGS", "LBS"]
    return weight_uom